=======
History
=======

0.1.0 (2018-01-05)
------------------

* First release on PyPI.

0.2.0 (2018-04-11)
------------------

* Recipes were added in
* Custom Checkers
* Multiple master files can be used
* Module associated files to find master configs
* Detail finding in cli to get help on the fly

0.3.0 (2018-08-10)
------------------

* Added the ability require an config entry be a list
* Added significant unit tests

0.4.0 (2019-07-19)
------------------

* Added in url datatype
* Added Datetime Ordered data type for start stop options
* Added in an inidiff script for comparing config files

0.5.0 (2019-08-22)
------------------

* Fixed bug relating to Datetime Ordered Pairs
* Added in inimake script for creating scripts from scratch
* Added in more unittests (54% coverage)


0.6.0 (2019-10-16)
------------------

* Built in a brand new feature for migrating large changes in configs
* Added bounds checking for type checking allowing for continuous types
* Fixes for issues: 25_ , 27_ , 31_ , 32_


0.7.0 (2019-10-22)
------------------
* Restructure the checkers some to better handle types
* Fixed several broken tests.

.. _25: https://github.com/USDA-ARS-NWRC/inicheck/issues/25
.. _27: https://github.com/USDA-ARS-NWRC/inicheck/issues/27
.. _31: https://github.com/USDA-ARS-NWRC/inicheck/issues/31
.. _32: https://github.com/USDA-ARS-NWRC/inicheck/issues/32
